@@ -1,6 +1,9 @@
 package DBIx::Class::InflateColumn::JSON2Object::Role::Storable;
-use 5.014;
+
 # ABSTRACT: simplified MooseX::Storage clone with enhanced JSON boolean handling
+our $VERSION = '0.906'; # VERSION
+
+use 5.014;
 
 use Moose::Role;
 
@@ -91,7 +94,7 @@ DBIx::Class::InflateColumn::JSON2Object::Role::Storable - simplified MooseX::Sto
 
 =head1 VERSION
 
-version 0.905
+version 0.906
 
 =head1 NAME
 
@@ -114,11 +117,11 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Thomas Klausner.
+This software is copyright (c) 2017 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
